import numpy as np
import matplotlib.pyplot as plt


def mcmc_sampling(eta = 1.0, n = 1000):
    """
            Metropolis algorithm
    """
    def p_dist(x, y):
        v = (x**2 + y**2) ** 0.5
        if v <= 0.0 or v > 1.0:
            p = 0.0
        else:
            p = v ** (eta - 1.0)
        return p

    def next_xy(x0, y0):
        x1 = np.random.normal(x0, 0.3)
        y1 = np.random.normal(y0, 0.3)
        t_p = p_dist(x1, y1)
        if t_p <= 0.0:
            x1 = x0
            y1 = y0
        else:
            a = t_p / p_dist(x0, y0)
            if np.random.uniform() > a:
                x1 = x0
                y1 = y0
        return x1, y1

    x0 = 0.5
    y0 = 0.5
    for i in range(100):
        x0, y0 = next_xy(x0, y0)
    Xs = []
    Ys = []
    xt = x0
    yt = y0
    for i in range(n):
        xt, yt = next_xy(xt, yt)
        Xs.append(xt)
        Ys.append(yt)

    return Xs, Ys

eta = float(input('eta = '))

Xs, Ys = mcmc_sampling(eta = eta, n = 10_000)

plt.subplots(figsize = (8, 8))
plt.subplot(2,2,1)
plt.plot(Xs, Ys, 'o', alpha = 0.3)
plt.xlabel('X', fontsize = 14)
plt.ylabel('Y', fontsize = 14)
plt.title('$\eta$ = {0:.2f}'.format(eta), fontsize = 16)

Ds = []
for i in range(len(Xs)):
    Ds.append(((Xs[i]**2) + (Ys[i]**2))**0.5)
plt.subplot(2,2,2)
plt.hist(Ds)
plt.xlabel('Distance', fontsize = 14)
plt.title('Histogram of Distances', fontsize = 16)

plt.subplot(2,2,3)
plt.hist(Xs)
plt.xlabel('X', fontsize = 14)
plt.title('\nHistogram of X', fontsize = 16)

plt.subplot(2,2,4)
plt.hist(Ys)
plt.xlabel('Y', fontsize = 14)
plt.title('\nHistogram of Y', fontsize = 16)

plt.tight_layout()
plt.show()

    
            
