import pystan
import matplotlib.pyplot as plt

StanCode = """
    parameters {
        corr_matrix[3] corr;
    }
    model {
        corr ~ lkj_corr(%s);
    }
"""
eta = input('eta = ')

sm = pystan.StanModel(model_code = (StanCode % eta))
fit = sm.sampling(n_jobs = 1)
print(fit)

r12 = []
r13 = []
r23 = []
for r in fit['corr']:
    r12.append(r[0,1])
    r13.append(r[0,2])
    r23.append(r[1,2])

plt.subplots(figsize = (7,7))
plt.subplot(2,2,1)
plt.plot(r12, r13, 'o', alpha = 0.3)
plt.xlabel('r12\n', fontsize = 16)
plt.ylabel('\nr13', fontsize = 16)
plt.title('$\eta$ = {}'.format(eta))

plt.subplot(2,2,2)
plt.plot(r23, r13, 'o', alpha = 0.3)
plt.xlabel('r23\n', fontsize = 16)
plt.ylabel('\nr13', fontsize = 16)
plt.title('$\eta$ = {}'.format(eta))

plt.subplot(2,2,4)
plt.plot(r23, r12, 'o', alpha = 0.3)
plt.xlabel('r23\n', fontsize = 16)
plt.ylabel('\nr12', fontsize = 16)
plt.title('$\eta$ = {}'.format(eta))

plt.tight_layout()
plt.show()


plt.subplots(figsize = (5,9))
plt.subplot(3,1,1)
plt.hist(r12)
plt.title(' ', fontsize = 18)
plt.xlabel('r12', fontsize = 18)
plt.title('$\eta$ = {}'.format(eta))

plt.subplot(3,1,2)
plt.hist(r13)
plt.title(' ', fontsize = 18)
plt.xlabel('r13', fontsize = 18)
plt.title('$\eta$ = {}'.format(eta))

plt.subplot(3,1,3)
plt.hist(r23)
plt.title(' ', fontsize = 18)
plt.xlabel('r23', fontsize = 18)
plt.title('$\eta$ = {}'.format(eta))

plt.tight_layout()
plt.show()

import numpy as np

det_Rs = []
for R in fit['corr']:
    det_Rs.append(np.linalg.det(R))
    
plt.hist(det_Rs)
plt.xlabel('Det of Corr Matrix')
plt.title('$\eta$ = {}'.format(eta))
plt.show()
